import os
import mimetypes

from silk import Application, Response

class StaticFiles(Application):
    def __init__(self, root_dir, show_dir_listings=True, default_documents=None, **config):
        super(StaticFiles, self).__init__({'(?P<path>.*)': self.serve_files}, **config)
        self.config['STATIC_FILES_ROOT_DIR'] = root_dir
        self.config['STATIC_FILES_SHOW_DIR_LISTINGS'] = show_dir_listings
        self.config['STATIC_FILES_DEFAULT_DOCUMENTS'] = default_documents or ['index.html']
    
    def serve_files(request, config, path):
        real = os.path.realpath(path)
        root = config['STATIC_FILES_ROOT_DIR']
        if os.path.commonprefix([real,root]) == root:
            typ, encoding = mimetypes.guess_type(real)
            typ = typ or 'application/octet-stream'
            encoding = encoding or ''
            return Response(content_type=typ, content_encoding=encoding, body=open(real))
        return Response(status=404, '<h1>404 Not Found</h1>')
        